@@ -32,8 +32,8 @@ def gravatar_url_from_email(email, size=64, default=None):
                 'size': size, 'valid_sizes': _valid_gravatar_sizes})
 
     if not default:
-        default = "http://fedoraproject.org/static/images/" + \
-                  "fedora_infinity_%ix%i.png" % (size, size)
+        default = ("http://fedoraproject.org/static/images/"
+                   "fedora_infinity_%ix%i.png" % (size, size))
 
     return _kernel(email, size, default, service='gravatar')
 
