@@ -23,23 +23,25 @@ import unittest
 
 from fedmsg.tests.test_meta import Base
 
+from common import add_doc
+
 
 class TestKojiBuildTag(Base):
     """ Koji emits these messages when a build has a certain tag added to it.
     """
     expected_title = "buildsys.tag"
-    expected_subti = "ralph's stage-4.1.1-3.fc18 tagged into " + \
-        "f18-updates-testing-pending by bodhi"
-    expected_icon = "http://fedoraproject.org/w/uploads/2/20/" + \
-        "Artwork_DesignService_koji-icon-48.png"
+    expected_subti = ("ralph's stage-4.1.1-3.fc18 tagged into "
+                      "f18-updates-testing-pending by bodhi")
+    expected_icon = ("http://fedoraproject.org/w/uploads/2/20/"
+                     "Artwork_DesignService_koji-icon-48.png")
     expected_packages = set(['stage'])
     expected_usernames = set(['ralph', 'bodhi'])
     expected_objects = set([
         'builds/stage/4.1.1/3.fc18',
         'tags/f18-updates-testing-pending',
     ])
-    expected_link = "http://koji.fedoraproject.org/koji/" + \
-        "taginfo?tagID=216"
+    expected_link = ("http://koji.fedoraproject.org/koji/"
+                     "taginfo?tagID=216")
     msg = {
         "username": "apache",
         "i": 1,
@@ -60,18 +62,18 @@ class TestKojiBuildTag(Base):
 class TestKojiBuildUnTag(Base):
     """ Koji emits these messages anytime a tag is removed from a build. """
     expected_title = "buildsys.untag"
-    expected_subti = "ralph's globus-gram-job-manager-sge-1.5-2.fc16 " + \
-        "untagged from f16-updates-pending by bodhi"
-    expected_icon = "http://fedoraproject.org/w/uploads/2/20/" + \
-        "Artwork_DesignService_koji-icon-48.png"
+    expected_subti = ("ralph's globus-gram-job-manager-sge-1.5-2.fc16 "
+                      "untagged from f16-updates-pending by bodhi")
+    expected_icon = ("http://fedoraproject.org/w/uploads/2/20/"
+                     "Artwork_DesignService_koji-icon-48.png")
     expected_packages = set(['globus-gram-job-manager-sge'])
     expected_usernames = set(['ralph', 'bodhi'])
     expected_objects = set([
         'builds/globus-gram-job-manager-sge/1.5/2.fc16',
         'tags/f16-updates-pending',
     ])
-    expected_link = "http://koji.fedoraproject.org/koji/" + \
-        "taginfo?tagID=216"
+    expected_link = ("http://koji.fedoraproject.org/koji/"
+                     "taginfo?tagID=216")
     msg = {
         "username": "apache",
         "i": 85,
@@ -105,15 +107,15 @@ class TestKojiBuildStateChangeStart(Base):
     """
     expected_title = "buildsys.build.state.change"
     expected_subti = "ralph's eclipse-ptp-6.0.3-1.fc19 started building"
-    expected_icon = "http://fedoraproject.org/w/uploads/2/20/" + \
-        "Artwork_DesignService_koji-icon-48.png"
+    expected_icon = ("http://fedoraproject.org/w/uploads/2/20/"
+                     "Artwork_DesignService_koji-icon-48.png")
     expected_usernames = set(['ralph'])
     expected_packages = set(['eclipse-ptp'])
     expected_objects = set([
         'builds/eclipse-ptp/6.0.3/1.fc19'
     ])
-    expected_link = "http://koji.fedoraproject.org/koji/" + \
-        "buildinfo?buildID=12345"
+    expected_link = ("http://koji.fedoraproject.org/koji/"
+                     "buildinfo?buildID=12345")
     msg = {
         "username": "apache",
         "i": 1,
@@ -143,15 +145,15 @@ class TestKojiBuildStateChangeStartNoOwner(Base):
     """
     expected_title = "buildsys.build.state.change"
     expected_subti = "eclipse-ptp-6.0.3-1.fc19 started building"
-    expected_icon = "http://fedoraproject.org/w/uploads/2/20/" + \
-        "Artwork_DesignService_koji-icon-48.png"
+    expected_icon = ("http://fedoraproject.org/w/uploads/2/20/"
+                     "Artwork_DesignService_koji-icon-48.png")
     expected_usernames = set([])
     expected_packages = set(['eclipse-ptp'])
     expected_objects = set([
         'builds/eclipse-ptp/6.0.3/1.fc19'
     ])
-    expected_link = "http://koji.fedoraproject.org/koji/" + \
-        "buildinfo?buildID=12345"
+    expected_link = ("http://koji.fedoraproject.org/koji/"
+                     "buildinfo?buildID=12345")
     msg = {
         "username": "apache",
         "i": 1,
@@ -186,15 +188,15 @@ class TestKojiBuildStateChangeFail(Base):
     """
     expected_title = "buildsys.build.state.change"
     expected_subti = "rmattes's eclipse-ptp-6.0.3-1.fc19 failed to build"
-    expected_icon = "http://fedoraproject.org/w/uploads/2/20/" + \
-        "Artwork_DesignService_koji-icon-48.png"
+    expected_icon = ("http://fedoraproject.org/w/uploads/2/20/"
+                     "Artwork_DesignService_koji-icon-48.png")
     expected_packages = set(['eclipse-ptp'])
     expected_usernames = set(['rmattes'])
     expected_objects = set([
         'builds/eclipse-ptp/6.0.3/1.fc19',
     ])
-    expected_link = "http://koji.fedoraproject.org/koji/" + \
-        "buildinfo?buildID=12345"
+    expected_link = ("http://koji.fedoraproject.org/koji/"
+                     "buildinfo?buildID=12345")
     msg = {
         "username": "apache",
         "i": 1,
@@ -217,15 +219,15 @@ class TestKojiRepoInit(Base):
     """ Koji emits these messages when a repository begins initializing. """
     expected_title = "buildsys.repo.init"
     expected_subti = 'Repo initialized:  f19-build'
-    expected_icon = "http://fedoraproject.org/w/uploads/2/20/" + \
-        "Artwork_DesignService_koji-icon-48.png"
+    expected_icon = ("http://fedoraproject.org/w/uploads/2/20/"
+                     "Artwork_DesignService_koji-icon-48.png")
     expected_packages = set([])
     expected_usernames = set([])
     expected_objects = set([
         'repos/f19-build',
     ])
-    expected_link = "http://koji.fedoraproject.org/koji/" + \
-        "taginfo?tagID=12345"
+    expected_link = ("http://koji.fedoraproject.org/koji/"
+                     "taginfo?tagID=12345")
     msg = {
         "username": "apache",
         "i": 2,
@@ -243,15 +245,15 @@ class TestKojiRepoDone(Base):
     """ Koji emits these messages when repo initialization finishes. """
     expected_title = "buildsys.repo.done"
     expected_subti = 'Repo done:  f19-build'
-    expected_icon = "http://fedoraproject.org/w/uploads/2/20/" + \
-        "Artwork_DesignService_koji-icon-48.png"
+    expected_icon = ("http://fedoraproject.org/w/uploads/2/20/"
+                     "Artwork_DesignService_koji-icon-48.png")
     expected_packages = set([])
     expected_usernames = set([])
     expected_objects = set([
         'repos/f19-build',
     ])
-    expected_link = "http://koji.fedoraproject.org/koji/" + \
-        "taginfo?tagID=12345"
+    expected_link = ("http://koji.fedoraproject.org/koji/"
+                     "taginfo?tagID=12345")
     msg = {
         "username": "apache",
         "i": 2,
@@ -269,8 +271,8 @@ class TestKojiPackageListChange(Base):
     """ Koji emits these messages a package listing changes. """
     expected_title = "buildsys.package.list.change"
     expected_subti = "Package list change for almanah:  'f17'"
-    expected_icon = "http://fedoraproject.org/w/uploads/2/20/" + \
-        "Artwork_DesignService_koji-icon-48.png"
+    expected_icon = ("http://fedoraproject.org/w/uploads/2/20/"
+                     "Artwork_DesignService_koji-icon-48.png")
     expected_packages = set(["almanah"])
     expected_usernames = set([])
     expected_objects = set([
@@ -287,5 +289,7 @@ class TestKojiPackageListChange(Base):
     }
 
 
+add_doc(locals())
+
 if __name__ == '__main__':
     unittest.main()
